﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2019 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HEAL.Attic;
using HeuristicLab.Core;
using System.Collections.Generic;

namespace HeuristicLab.Algorithms.EvolvmentModelsOfModels {
  [StorableType("83CF9650-98FF-454B-9072-82EA4D39C752")]
  public abstract class EMMMapBase<T> : Item where T : class {
    public List<T> ModelSet { get; set; }
    public List<int> ClusterNumber { get; set; }
    public List<List<int>> Map { get; set; }
    public double[,] Distances { get; set; }
    public int K { get; set; }

    protected abstract void CalculateDistances();
    protected abstract void CreateIslandMap(IRandom random, int k);
    public abstract T NewModelForInizializtion(IRandom random, out int cluster, out int treeNumber);

    [StorableConstructor]
    protected EMMMapBase(StorableConstructorFlag _) : base(_) { }
    protected EMMMapBase() { }

  }
}
